@@ -158,9 +158,9 @@ def modify_local(config):
         new_config['wdeployments'].append({
             'id': wd['id'],
             'owner': wd['owner'],
-            'cprovider': 'docker',
-            'cargs': [],
-            'image': "rerobots/hs-generic",
+            'cprovider': wd['cprovider'] if 'cprovider' in wd else 'docker',
+            'cargs': wd['cargs'] if 'cargs' in wd else [],
+            'image': wd.get('image', 'rerobots/hs-generic'),
             "container_name": "rrc",
         })
     with open(os.path.join(base_path, 'main'), 'wt') as fp:
